summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorLuke Shumaker <lukeshu@sbcglobal.net>2016-06-17 11:49:22 -0400
committerLuke Shumaker <lukeshu@sbcglobal.net>2016-06-17 11:49:22 -0400
commitc191af11616a3306b8e0a3650b6972eb61d2aba1 (patch)
treef5014a271d2c4c429113f4129d1d14ef73854470 /src
parent896fdc18c430d8f6a5e5bd417b9ab0d3254941da (diff)
rearrange the go packages a bit
Diffstat (limited to 'src')
-rw-r--r--src/cmd-nshd/.gitignore1
-rw-r--r--src/cmd-nshd/main.go.in (renamed from src/nshd/main.go.in)4
-rw-r--r--src/parabola_hackers/nslcd_backend/check_password.go (renamed from src/nshd/hackers_git/check_password.go)2
-rw-r--r--src/parabola_hackers/nslcd_backend/db_config.go (renamed from src/nshd/hackers_git/db_config.go)2
-rw-r--r--src/parabola_hackers/nslcd_backend/db_group.go (renamed from src/nshd/hackers_git/db_group.go)2
-rw-r--r--src/parabola_hackers/nslcd_backend/db_pam.go (renamed from src/nshd/hackers_git/db_pam.go)2
-rw-r--r--src/parabola_hackers/nslcd_backend/db_passwd.go (renamed from src/nshd/hackers_git/db_passwd.go)2
-rw-r--r--src/parabola_hackers/nslcd_backend/db_shadow.go (renamed from src/nshd/hackers_git/db_shadow.go)2
-rw-r--r--src/parabola_hackers/nslcd_backend/gid.go (renamed from src/nshd/hackers_git/gid.go)2
-rw-r--r--src/parabola_hackers/nslcd_backend/hackers.go (renamed from src/nshd/hackers_git/hackers.go)6
-rw-r--r--src/parabola_hackers/nslcd_backend/hackers_parse.go (renamed from src/nshd/hackers_git/hackers_parse.go)2
-rw-r--r--src/parabola_hackers/nslcd_backend/set.go (renamed from src/nshd/hackers_git/set.go)2
12 files changed, 15 insertions, 14 deletions
diff --git a/src/cmd-nshd/.gitignore b/src/cmd-nshd/.gitignore
new file mode 100644
index 0000000..00870e2
--- /dev/null
+++ b/src/cmd-nshd/.gitignore
@@ -0,0 +1 @@
+/main.go
diff --git a/src/nshd/main.go.in b/src/cmd-nshd/main.go.in
index 7dd4cae..d888f27 100644
--- a/src/nshd/main.go.in
+++ b/src/cmd-nshd/main.go.in
@@ -19,12 +19,12 @@ package main
import (
"lukeshu.com/git/go/libnslcd.git/systemd"
- "nshd/hackers_git"
+ hackers_nslcd_backend "parabola_hackers/nslcd_backend"
"os"
)
func main() {
- backend := &hackers_git.Hackers{
+ backend := &hackers_nslcd_backend.Hackers{
CfgFilename: "@conf_file@",
YamlCat: "@bindir@/meta-cat",
}
diff --git a/src/nshd/hackers_git/check_password.go b/src/parabola_hackers/nslcd_backend/check_password.go
index 84a5a24..1458b6f 100644
--- a/src/nshd/hackers_git/check_password.go
+++ b/src/parabola_hackers/nslcd_backend/check_password.go
@@ -14,7 +14,7 @@
// License along with this manual; if not, see
// <http://www.gnu.org/licenses/>.
-package hackers_git
+package hackers_nslcd_backend
import "lukeshu.com/git/go/libgnulinux.git/crypt"
diff --git a/src/nshd/hackers_git/db_config.go b/src/parabola_hackers/nslcd_backend/db_config.go
index cdbb7db..934498d 100644
--- a/src/nshd/hackers_git/db_config.go
+++ b/src/parabola_hackers/nslcd_backend/db_config.go
@@ -14,7 +14,7 @@
// License along with this manual; if not, see
// <http://www.gnu.org/licenses/>.
-package hackers_git
+package hackers_nslcd_backend
import (
p "lukeshu.com/git/go/libnslcd.git/proto"
diff --git a/src/nshd/hackers_git/db_group.go b/src/parabola_hackers/nslcd_backend/db_group.go
index af1ac2c..8990fad 100644
--- a/src/nshd/hackers_git/db_group.go
+++ b/src/parabola_hackers/nslcd_backend/db_group.go
@@ -14,7 +14,7 @@
// License along with this manual; if not, see
// <http://www.gnu.org/licenses/>.
-package hackers_git
+package hackers_nslcd_backend
import (
p "lukeshu.com/git/go/libnslcd.git/proto"
diff --git a/src/nshd/hackers_git/db_pam.go b/src/parabola_hackers/nslcd_backend/db_pam.go
index 977104e..6b2a7c7 100644
--- a/src/nshd/hackers_git/db_pam.go
+++ b/src/parabola_hackers/nslcd_backend/db_pam.go
@@ -14,7 +14,7 @@
// License along with this manual; if not, see
// <http://www.gnu.org/licenses/>.
-package hackers_git
+package hackers_nslcd_backend
import (
"crypto/rand"
diff --git a/src/nshd/hackers_git/db_passwd.go b/src/parabola_hackers/nslcd_backend/db_passwd.go
index d6e4f16..514a8b3 100644
--- a/src/nshd/hackers_git/db_passwd.go
+++ b/src/parabola_hackers/nslcd_backend/db_passwd.go
@@ -14,7 +14,7 @@
// License along with this manual; if not, see
// <http://www.gnu.org/licenses/>.
-package hackers_git
+package hackers_nslcd_backend
import (
p "lukeshu.com/git/go/libnslcd.git/proto"
diff --git a/src/nshd/hackers_git/db_shadow.go b/src/parabola_hackers/nslcd_backend/db_shadow.go
index 2df4026..26b1b05 100644
--- a/src/nshd/hackers_git/db_shadow.go
+++ b/src/parabola_hackers/nslcd_backend/db_shadow.go
@@ -14,7 +14,7 @@
// License along with this manual; if not, see
// <http://www.gnu.org/licenses/>.
-package hackers_git
+package hackers_nslcd_backend
import (
p "lukeshu.com/git/go/libnslcd.git/proto"
diff --git a/src/nshd/hackers_git/gid.go b/src/parabola_hackers/nslcd_backend/gid.go
index 852b9a3..eabdbd7 100644
--- a/src/nshd/hackers_git/gid.go
+++ b/src/parabola_hackers/nslcd_backend/gid.go
@@ -14,7 +14,7 @@
// License along with this manual; if not, see
// <http://www.gnu.org/licenses/>.
-package hackers_git
+package hackers_nslcd_backend
import "lukeshu.com/git/go/libgnulinux.git/getgr"
diff --git a/src/nshd/hackers_git/hackers_parse.go b/src/parabola_hackers/nslcd_backend/hackers_parse.go
index af8c913..b18fdf8 100644
--- a/src/nshd/hackers_git/hackers_parse.go
+++ b/src/parabola_hackers/nslcd_backend/hackers_parse.go
@@ -14,7 +14,7 @@
// License along with this manual; if not, see
// <http://www.gnu.org/licenses/>.
-package hackers_git
+package hackers_nslcd_backend
import (
"fmt"
diff --git a/src/nshd/hackers_git/set.go b/src/parabola_hackers/nslcd_backend/set.go
index f0cf454..7a01c01 100644
--- a/src/nshd/hackers_git/set.go
+++ b/src/parabola_hackers/nslcd_backend/set.go
@@ -14,7 +14,7 @@
// License along with this manual; if not, see
// <http://www.gnu.org/licenses/>.
-package hackers_git
+package hackers_nslcd_backend
func set2list(set map[string]bool) []string {
list := make([]string, len(set))
diff --git a/src/nshd/hackers_git/hackers.go b/src/parabola_hackers/nslcd_backend/hackers.go
index b9a0b9a..66312c6 100644
--- a/src/nshd/hackers_git/hackers.go
+++ b/src/parabola_hackers/nslcd_backend/hackers.go
@@ -14,9 +14,9 @@
// License along with this manual; if not, see
// <http://www.gnu.org/licenses/>.
-// Package hackers_git is an nslcd_server Backend that speaks to
-// hackers.git.
-package hackers_git
+// Package hackers_nslcd_backend is an nslcd_server Backend that
+// speaks to hackers.git.
+package hackers_nslcd_backend
import (
"lukeshu.com/git/go/libnslcd.git/proto"